pub enum Annotation<Identifier = String> {
Atom(Identifier),
Call(AnnotationCall<Identifier>),
}Expand description
Additional information provided in a standardized format for declarations, constraints, or solve objectives
In MiniZinc annotations can both be added explicitly in the model, or can be added during compilation process.
Note that annotations are generally defined either in the MiniZinc standard library or in a solver’s redefinition library. Solvers are encouraged to rewrite annotations in their redefinitions library when required.
Variants
Atom(Identifier)
Atom annotation (i.e., a single Identifier)
Call(AnnotationCall<Identifier>)
Call annotation