LinkError

Enum LinkError 

pub enum LinkError {
    IdentifierError {
        ident: String,
        err: String,
    },
    UnknownReference(String),
    NestedArray(String),
    DuplicateDefinition(String),
}
Error produced while linking an variable and array references of the model.

Variants



IdentifierError

A predicate or annotation identifier could not be interned.

Fields

ident: String

The identifier string that failed to intern.

err: String

The interner error message.



UnknownReference(String)

A named literal could not be resolved to a variable or array.



NestedArray(String)

A named array identifier that was used as a literal.



DuplicateDefinition(String)

Duplicate definition of a name.